@@ -1,7 +1,7 @@
 <?php
 /**
  * Copyright 2007 Maintainable Software, LLC
- * Copyright 2008-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2015 Horde LLC (http://www.horde.org/)
  *
  * @author     Mike Naberezny <mike@maintainable.com>
  * @author     Derek DeVries <derek@maintainable.com>
@@ -575,11 +575,11 @@ abstract class Horde_Db_Adapter_Base implements Horde_Db_Adapter
     {
         $query = sprintf(
             'INSERT INTO %s (%s) VALUES (%s)',
-            $table,
+            $this->quoteTableName($table),
             implode(', ', array_map(array($this, 'quoteColumnName'), array_keys($fields))),
             implode(', ', array_fill(0, count($fields), '?'))
         );
-        return $this->insert($query, $fields, $pk, $idValue);
+        return $this->insert($query, $fields, null, $pk, $idValue);
     }
 
     /**
@@ -600,6 +600,39 @@ abstract class Horde_Db_Adapter_Base implements Horde_Db_Adapter
         return $this->_rowCount;
     }
 
+    /**
+     * Updates rows including BLOBs into a table.
+     *
+     * @since Horde_Db 2.2.0
+     *
+     * @param string $table        The table name.
+     * @param array $fields        A hash of column names and values. BLOB
+     *                             columns must be provided as
+     *                             Horde_Db_Value_Binary objects.
+     * @param string|array $where  A WHERE clause. Either a complete clause or
+     *                             an array containing a clause with
+     *                             placeholders and a list of values.
+     *
+     * @throws Horde_Db_Exception
+     */
+    public function updateBlob($table, $fields, $where = null)
+    {
+        if (is_array($where)) {
+            $where = $this->_replaceParameters($where[0], $where[1]);
+        }
+        $fnames = array();
+        foreach (array_keys($fields) as $field) {
+            $fnames[] = $this->quoteColumnName($field) . ' = ?';
+        }
+        $query = sprintf(
+            'UPDATE %s SET %s%s',
+            $this->quoteTableName($table),
+            implode(', ', $fnames),
+            strlen($where) ? ' WHERE ' . $where : ''
+        );
+        return $this->update($query, $fields);
+    }
+
     /**
      * Executes the delete statement and returns the number of rows affected.
      *
@@ -797,7 +830,7 @@ abstract class Horde_Db_Adapter_Base implements Horde_Db_Adapter
     protected function _cacheKey($key)
     {
         if (!isset($this->_cachePrefix)) {
-            $this->_cachePrefix = get_class($this) . hash((PHP_MINOR_VERSION >= 4) ? 'fnv132' : 'sha1', serialize($this->_config));
+            $this->_cachePrefix = get_class($this) . hash((version_compare(PHP_VERSION, '5.4', '>=')) ? 'fnv132' : 'sha1', serialize($this->_config));
         }
 
         return $this->_cachePrefix . $key;
