@@ -1,7 +1,7 @@
 <?php
 /**
  * Copyright 2007 Maintainable Software, LLC
- * Copyright 2008-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2015 Horde LLC (http://www.horde.org/)
  *
  * @author     Mike Naberezny <mike@maintainable.com>
  * @author     Derek DeVries <derek@maintainable.com>
@@ -118,6 +118,10 @@ class Horde_Db_Adapter_Base_TableDefinition implements ArrayAccess, IteratorAggr
      */
     public function column($name, $type, $options = array())
     {
+        if ($name == $this->_primaryKey) {
+            throw new LogicException($name . ' has already been added as a primary key');
+        }
+
         $options = array_merge(
             array('limit'         => null,
                   'precision'     => null,
