@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
  *
  * @author     Jan Schneider <jan@horde.org>
  * @license    http://www.horde.org/licenses/bsd
@@ -116,6 +116,17 @@ class Horde_Db_Adapter_Oci8 extends Horde_Db_Adapter_Base
         $this->execute("ALTER SESSION SET NLS_DATE_FORMAT = 'YYYY-MM-DD HH24:MI:SS'");
     }
 
+    /**
+     * Disconnect from db
+     */
+    public function disconnect()
+    {
+        if ($this->_connection) {
+            oci_close($this->_connection);
+        }
+        parent::disconnect();
+    }
+
 
     /*#########################################################################
     # Quoting
@@ -284,7 +295,7 @@ class Horde_Db_Adapter_Oci8 extends Horde_Db_Adapter_Base
         $descriptors = array();
         foreach ($lobs as $name => $lob) {
             $descriptors[$name] = oci_new_descriptor($this->_connection, OCI_DTYPE_LOB);
-            oci_bind_by_name($stmt, ':' . $name, $descriptors[$name], -1, OCI_B_BLOB);
+            oci_bind_by_name($stmt, ':' . $name, $descriptors[$name], -1, $lob instanceof Horde_Db_Value_Binary ? OCI_B_BLOB : OCI_B_CLOB);
         }
 
         $flags = $lobs
@@ -365,16 +376,7 @@ class Horde_Db_Adapter_Oci8 extends Horde_Db_Adapter_Base
      */
     public function insertBlob($table, $fields, $pk = null, $idValue = null)
     {
-        $blobs = $locators = array();
-        foreach ($fields as $column => &$field) {
-            if ($field instanceof Horde_Db_Value_Binary) {
-                $blobs[$this->quoteColumnName($column)] = $field;
-                $locators[] = ':' . $this->quoteColumnName($column);
-                $field = 'EMPTY_BLOB()';
-            } else {
-                $field = $this->quote($field);
-            }
-        }
+        list($fields, $blobs, $locators) = $this->_prepareBlobs($fields);
 
         $sql = 'INSERT INTO ' . $this->quoteTableName($table) . ' ('
             . implode(
@@ -391,6 +393,75 @@ class Horde_Db_Adapter_Oci8 extends Horde_Db_Adapter_Base
             : $this->selectValue('SELECT id FROM horde_db_autoincrement');
     }
 
+    /**
+     * Updates rows including BLOBs into a table.
+     *
+     * @since Horde_Db 2.2.0
+     *
+     * @param string $table        The table name.
+     * @param array $fields        A hash of column names and values. BLOB
+     *                             columns must be provided as
+     *                             Horde_Db_Value_Binary objects.
+     * @param string|array $where  A WHERE clause. Either a complete clause or
+     *                             an array containing a clause with
+     *                             placeholders and a list of values.
+     *
+     * @throws Horde_Db_Exception
+     */
+    public function updateBlob($table, $fields, $where = null)
+    {
+        list($fields, $blobs, $locators) = $this->_prepareBlobs($fields);
+
+        if (is_array($where)) {
+            $where = $this->_replaceParameters($where[0], $where[1]);
+        }
+
+        $fnames = array();
+        foreach ($fields as $field => $value) {
+            $fnames[] = $this->quoteColumnName($field) . ' = ' . $value;
+        }
+
+        $sql = sprintf(
+            'UPDATE %s SET %s%s RETURNING %s INTO %s',
+            $this->quoteTableName($table),
+            implode(', ', $fnames),
+            strlen($where) ? ' WHERE ' . $where : '',
+            implode(', ', array_keys($blobs)),
+            implode(', ', $locators)
+        );
+
+        $this->execute($sql, null, null, $blobs);
+
+        return $this->_rowCount;
+    }
+
+    /**
+     * Prepares a list of field values to be consumed by insertBlob() or
+     * updateBlob().
+     *
+     * @param array $fields  A hash of column names and values. BLOB columns
+     *                       must be provided as Horde_Db_Value_Binary objects.
+     *
+     * @return array  A list of fields, blobs, and locators.
+     */
+    protected function _prepareBlobs($fields)
+    {
+        $blobs = $locators = array();
+        foreach ($fields as $column => &$field) {
+            if ($field instanceof Horde_Db_Value_Binary ||
+                $field instanceof Horde_Db_Value_Text) {
+                $blobs[$this->quoteColumnName($column)] = $field;
+                $locators[] = ':' . $this->quoteColumnName($column);
+                $field = $field instanceof Horde_Db_Value_Binary
+                    ? 'EMPTY_BLOB()'
+                    : 'EMPTY_CLOB()';
+            } else {
+                $field = $this->quote($field);
+            }
+        }
+        return array($fields, $blobs, $locators);
+    }
+
     /**
      * Begins the transaction (and turns off auto-committing).
      */
