@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
  *
  * @author     Jan Schneider <jan@horde.org>
  * @license    http://www.horde.org/licenses/bsd
@@ -380,7 +380,11 @@ class Horde_Db_Adapter_Oracle_Schema extends Horde_Db_Adapter_Base_Schema
             $sql
         );
 
-        return $this->execute($sql);
+        $this->execute($sql);
+
+        if ($type == 'autoincrementKey') {
+            $this->createAutoincrementTrigger($tableName, $columnName);
+        }
     }
 
     /**
@@ -395,6 +399,7 @@ class Horde_Db_Adapter_Oracle_Schema extends Horde_Db_Adapter_Base_Schema
         $sql = sprintf('ALTER TABLE %s DROP COLUMN %s',
                        $this->quoteTableName($tableName),
                        $this->quoteColumnName($columnName));
+        $this->removeAutoincrementTrigger($tableName, $columnName);
         return $this->execute($sql);
     }
 
@@ -430,8 +435,10 @@ class Horde_Db_Adapter_Oracle_Schema extends Horde_Db_Adapter_Base_Schema
         $columnOptions = array(
             'limit' => $column->getLimit(),
             'default' => $column->getDefault(),
-            'null' => $column->isNull()
         );
+        if (!$column->isNull()) {
+            $columnOptions['null'] = false;
+        }
         $old = $this->addColumnOptions(
             $this->typeToSql(
                 $column->getType(),
@@ -496,28 +503,43 @@ class Horde_Db_Adapter_Oracle_Schema extends Horde_Db_Adapter_Base_Schema
         if ($type == 'binary' && $column->getType() != 'binary') {
             $this->beginDbTransaction();
             $this->addColumn($tableName, $columnName . '_tmp', $type, $options);
+            $this->execute('
+CREATE OR REPLACE FUNCTION CLOB_TO_BLOB (p_clob CLOB) RETURN BLOB
+AS
+    l_blob          BLOB;
+    l_dest_offset   INTEGER := 1;
+    l_source_offset INTEGER := 1;
+    l_lang_context  INTEGER := DBMS_LOB.DEFAULT_LANG_CTX;
+    l_warning       INTEGER := DBMS_LOB.WARN_INCONVERTIBLE_CHAR;
+BEGIN
+    DBMS_LOB.CREATETEMPORARY(l_blob, TRUE);
+    DBMS_LOB.CONVERTTOBLOB
+    (
+        dest_lob     => l_blob,
+        src_clob     => p_clob,
+        amount       => DBMS_LOB.LOBMAXSIZE,
+        dest_offset  => l_dest_offset,
+        src_offset   => l_source_offset,
+        blob_csid    => DBMS_LOB.DEFAULT_CSID,
+        lang_context => l_lang_context,
+        warning      => l_warning
+    );
+    RETURN l_blob;
+END;
+            ');
             $this->update(sprintf(
-                'UPDATE %s SET %s = UTL_RAW.CAST_TO_RAW(%s) WHERE LENGTH(%3$s) <= 2000',
+                'UPDATE %s SET %s = CLOB_TO_BLOB(%s) WHERE %s IS NOT NULL',
+                $this->quoteTableName($tableName),
+                $this->quoteColumnName($columnName . '_tmp'),
+                $this->quoteColumnName($columnName),
+                $this->quoteColumnName($columnName)
+            ));
+            $this->update(sprintf(
+                'UPDATE %s SET %s = NULL WHERE %s IS NULL',
                 $this->quoteTableName($tableName),
                 $this->quoteColumnName($columnName . '_tmp'),
                 $this->quoteColumnName($columnName)
             ));
-            $this->execute(sprintf(
-                'DECLARE CURSOR cur IS SELECT %s, %s FROM %s WHERE LENGTH(%s) > 2000 FOR UPDATE; new blob; old %s; BEGIN OPEN cur; IF cur%%ISOPEN THEN LOOP FETCH cur INTO old, new; EXIT WHEN cur%%NOTFOUND; DBMS_LOB.WRITE(new, LENGTH(old), 1, UTL_RAW.CAST_TO_RAW(SUBSTR(old, 1, LENGTH(old)))); END LOOP; CLOSE cur; END IF; END;',
-                $this->quoteColumnName($columnName),
-                $this->quoteColumnName($columnName . '_tmp'),
-                $this->quoteTableName($tableName),
-                $this->quoteColumnName($columnName),
-                $this->typeToSql(
-                    $column->getType(),
-                    $column->getType() == 'integer' || $column->getType() == 'text'
-                        ? null
-                        : $column->getLimit(),
-                    $column->precision(),
-                    $column->scale(),
-                    $column->isUnsigned()
-                )
-            ));
             $this->removeColumn($tableName, $columnName);
             $this->renameColumn($tableName, $columnName . '_tmp', $columnName);
             $this->commitDbTransaction();
@@ -592,16 +614,37 @@ class Horde_Db_Adapter_Oracle_Schema extends Horde_Db_Adapter_Base_Schema
      */
     public function createAutoincrementTrigger($tableName, $columnName)
     {
+        // Build the table that holds the last autoincremented value. Used for
+        // example for returning the ID from last INSERT.
         $id = $tableName . '_' . $columnName;
         if (!$this->selectValue('SELECT 1 FROM USER_TABLES WHERE TABLE_NAME = \'HORDE_DB_AUTOINCREMENT\'')) {
             $this->execute('CREATE TABLE horde_db_autoincrement (id INTEGER)');
             $this->execute('INSERT INTO horde_db_autoincrement (id) VALUES (0)');
         }
+
+        // Create a sequence that automatically increments when queried with
+        // .NEXTVAL.
         $sequence = $this->_truncate($id . '_seq');
-        $this->execute(sprintf(
+        $sql = sprintf(
             'CREATE SEQUENCE %s',
             $sequence
-        ));
+        );
+        // See if the column already has values, to start the sequence at a
+        // higher value.
+        $max = $this->selectValue(
+            sprintf(
+                'SELECT MAX(%s) FROM %s',
+                $this->quoteColumnName($columnName),
+                $tableName
+            )
+        );
+        if ($max) {
+            $sql .= ' MINVALUE ' . ($max + 1);
+        }
+        $this->execute($sql);
+
+        // Create the actual trigger that inserts the next value from the
+        // sequence into the autoincrementKey column when inserting a row.
         $this->execute(sprintf(
             'CREATE OR REPLACE TRIGGER %s BEFORE INSERT ON %s FOR EACH ROW DECLARE increment INTEGER; BEGIN SELECT %s.NEXTVAL INTO :NEW.%s FROM dual; SELECT %s.CURRVAL INTO increment FROM dual; UPDATE horde_db_autoincrement SET id = increment; END;',
             $this->_truncate($id . '_trig'),
@@ -615,16 +658,20 @@ class Horde_Db_Adapter_Oracle_Schema extends Horde_Db_Adapter_Base_Schema
     /**
      * Drops sequences and triggers for an autoincrementKey column.
      *
+     * If $columnName is specified, the sequences and triggers are only dropped
+     * if $columnName is actually an autoincrementKey column.
+     *
      * @since Horde_Db 2.1.0
      *
      * @param string $tableName   A table name.
      * @param string $columnName  A column name.
      */
-    public function removeAutoincrementTrigger($name)
+    public function removeAutoincrementTrigger($tableName, $columnName = null)
     {
-        $pk = $this->primaryKey($name);
-        if (count($pk->columns) == 1) {
-            $prefix = $name . '_' . $pk->columns[0];
+        $pk = $this->primaryKey($tableName);
+        if (count($pk->columns) == 1 &&
+            (!$columnName || $pk->columns[0] == $columnName)) {
+            $prefix = $tableName . '_' . $pk->columns[0];
             try {
                 $this->execute(sprintf(
                     'DROP SEQUENCE %s',
