@@ -1,7 +1,7 @@
 <?php
 /**
  * Copyright 2007 Maintainable Software, LLC
- * Copyright 2008-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2015 Horde LLC (http://www.horde.org/)
  *
  * @author     Mike Naberezny <mike@maintainable.com>
  * @author     Derek DeVries <derek@maintainable.com>
@@ -362,6 +362,35 @@ class Horde_Db_Adapter_SplitRead implements Horde_Db_Adapter
         return $result;
     }
 
+    /**
+     * Inserts a row including BLOBs into a table.
+     *
+     * @since Horde_Db 2.1.0
+     *
+     * @param string $table     The table name.
+     * @param array $fields     A hash of column names and values. BLOB columns
+     *                          must be provided as Horde_Db_Value_Binary
+     *                          objects.
+     * @param string $pk        The primary key column.
+     * @param integer $idValue  The primary key value. This parameter is
+     *                          required if the primary key is inserted
+     *                          manually.
+     *
+     * @return integer  Last inserted ID.
+     * @throws Horde_Db_Exception
+     */
+    public function insertBlob($table, $fields, $pk = null, $idValue = null)
+    {
+        $result = $this->_write->insertBlob($table, $fields, $pk, $idValue);
+        $this->_lastQuery = $this->_write->getLastQuery();
+
+        // Once doing writes, keep using the write backend even for reads
+        // at least during the same request, to help against stale data.
+        $this->_read = $this->_write;
+
+        return $result;
+    }
+
     /**
      * Executes the update statement and returns the number of rows affected.
      *
@@ -386,6 +415,30 @@ class Horde_Db_Adapter_SplitRead implements Horde_Db_Adapter
         return $result;
     }
 
+    /**
+     * Updates rows including BLOBs into a table.
+     *
+     * @since Horde_Db 2.2.0
+     *
+     * @param string $table  The table name.
+     * @param array $fields  A hash of column names and values. BLOB columns
+     *                       must be provided as Horde_Db_Value_Binary objects.
+     * @param string $where  A WHERE clause.
+     *
+     * @throws Horde_Db_Exception
+     */
+    public function updateBlob($table, $fields, $where = '')
+    {
+        $result = $this->_write->updateBlob($table, $fields, $where);
+        $this->_lastQuery = $this->_write->getLastQuery();
+
+        // Once doing writes, keep using the write backend even for reads
+        // at least during the same request, to help against stale data.
+        $this->_read = $this->_write;
+
+        return $result;
+    }
+
     /**
      * Executes the delete statement and returns the number of rows affected.
      *
