@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2006-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2006-2015 Horde LLC (http://www.horde.org/)
  *
  * @author     Chuck Hagenbuch <chuck@horde.org>
  * @license    http://www.horde.org/licenses/bsd
@@ -9,8 +9,8 @@
  */
 
 /**
- * Encapsulation object for binary values to be used in SQL statements to ensure
- * proper quoting, escaping, retrieval, etc.
+ * Encapsulation object for binary values to be used in SQL statements to
+ * ensure proper quoting, escaping, retrieval, etc.
  *
  * @author     Chuck Hagenbuch <chuck@horde.org>
  * @license    http://www.horde.org/licenses/bsd
@@ -21,9 +21,11 @@ class Horde_Db_Value_Binary implements Horde_Db_Value
 {
     /**
      * Binary value to be quoted
+     *
      * @var string
+     * @since Horde_Db 2.1.0
      */
-    protected $_value;
+    public $value;
 
     /**
      * Constructor
@@ -32,7 +34,7 @@ class Horde_Db_Value_Binary implements Horde_Db_Value
      */
     public function __construct($binaryValue)
     {
-        $this->_value = $binaryValue;
+        $this->value = $binaryValue;
     }
 
     /**
@@ -40,6 +42,6 @@ class Horde_Db_Value_Binary implements Horde_Db_Value
      */
     public function quote(Horde_Db_Adapter $db)
     {
-        return $db->quoteBinary($this->_value);
+        return $db->quoteBinary($this->value);
     }
 }
