@@ -1,7 +1,7 @@
 <?php
 /**
  * Copyright 2007 Maintainable Software, LLC
- * Copyright 2008-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2015 Horde LLC (http://www.horde.org/)
  *
  * @author     Mike Naberezny <mike@maintainable.com>
  * @author     Derek DeVries <derek@maintainable.com>
@@ -32,11 +32,11 @@ abstract class Horde_Db_Adapter_TestBase extends Horde_Test_Case
 
     protected static $_skip = true;
 
-    protected static $_reason = 'The MySQL adapter is not available';
+    protected static $_reason;
 
     protected $_conn;
 
-    static protected function _getConnection($overrides = array())
+    protected static function _getConnection($overrides = array())
     {
         throw new LogicException('_getConnection() must be implemented in a sub-class.');
     }
@@ -201,6 +201,35 @@ abstract class Horde_Db_Adapter_TestBase extends Horde_Test_Case
         $this->assertEquals(7, $result);
     }
 
+    public function testInsertBlob()
+    {
+        $this->_createTable();
+
+        $result = $this->_conn->insertBlob(
+            'unit_tests',
+            array(
+                'id' => 7,
+                'integer_value' => 999,
+                'blob_value' => new Horde_Db_Value_Binary(str_repeat("\0", 5000))
+            ),
+            null,
+            7
+        );
+        $this->assertEquals(7, $result);
+
+        $result = $this->_conn->insertBlob(
+            'unit_tests',
+            array(
+                'id' => 8,
+                'integer_value' => 1000,
+                'text_value' => new Horde_Db_Value_Text(str_repeat('X', 5000))
+            ),
+            null,
+            8
+        );
+        $this->assertEquals(8, $result);
+    }
+
     public function testUpdate()
     {
         $this->_createTable();
@@ -211,6 +240,29 @@ abstract class Horde_Db_Adapter_TestBase extends Horde_Test_Case
         $this->assertEquals(1, $result);
     }
 
+    public function testUpdateBlob()
+    {
+        $this->_createTable();
+
+        $result = $this->_conn->updateBlob(
+            'unit_tests',
+            array(
+                'blob_value' => new Horde_Db_Value_Binary(str_repeat("\0", 5000))
+            ),
+            'id = 1'
+        );
+        $this->assertEquals(1, $result);
+
+        $result = $this->_conn->updateBlob(
+            'unit_tests',
+            array(
+                'text_value' => new Horde_Db_Value_Text(str_repeat('X', 5000))
+            ),
+            'id = 1'
+        );
+        $this->assertEquals(1, $result);
+    }
+
     public function testDelete()
     {
         $this->_createTable();
@@ -758,6 +810,76 @@ abstract class Horde_Db_Adapter_TestBase extends Horde_Test_Case
     }
 
 
+    /*##########################################################################
+    # Autoincrement Management
+    ##########################################################################*/
+
+    public function testAutoIncrementWithTypeInColumn()
+    {
+        $table = $this->_conn->createTable('autoinc', array('autoincrementKey' => false));
+        $table->column('foo', 'autoincrementKey');
+        $table->column('bar', 'integer');
+        $table->end();
+
+        try {
+        $this->assertEquals(1, $this->_conn->insert('INSERT INTO autoinc (bar) VALUES(5)'));
+        } catch (Exception $e) {
+            var_dump($this->_conn->getLastQuery());
+            throw $e;
+        }
+        $this->assertEquals(2, $this->_conn->insert('INSERT INTO autoinc (bar) VALUES(6)'));
+        $this->assertEquals(2, $this->_conn->selectValue('SELECT foo FROM autoinc WHERE bar = 6'));
+    }
+
+    /**
+     * @expectedException LogicException
+     * @expectedExceptionMessage foo has already been added as a primary key
+     */
+    public function testAutoIncrementWithTypeInTableAndColumnDefined()
+    {
+        $table = $this->_conn->createTable('autoincrement', array('autoincrementKey' => 'foo'));
+        $table->column('foo', 'integer');
+        $table->column('bar', 'integer');
+        $table->end();
+    }
+
+    public function testAutoIncrementWithTypeInTable()
+    {
+        $table = $this->_conn->createTable('autoinc', array('autoincrementKey' => 'foo'));
+        $table->column('bar', 'integer');
+        $table->end();
+
+        $this->assertEquals(1, $this->_conn->insert('INSERT INTO autoinc (bar) VALUES(5)'));
+        $this->assertEquals(2, $this->_conn->insert('INSERT INTO autoinc (bar) VALUES(6)'));
+        $this->assertEquals(2, $this->_conn->selectValue('SELECT foo FROM autoinc WHERE bar = 6'));
+    }
+
+    public function testAutoIncrementWithAddColumn()
+    {
+        $table = $this->_conn->createTable('autoinc', array('autoincrementKey' => false));
+        $table->column('bar', 'integer');
+        $table->end();
+        $this->_conn->addColumn('autoinc', 'foo', 'autoincrementKey');
+
+        $this->assertEquals(1, $this->_conn->insert('INSERT INTO autoinc (bar) VALUES(5)'));
+        $this->assertEquals(2, $this->_conn->insert('INSERT INTO autoinc (bar) VALUES(6)'));
+        $this->assertEquals(2, $this->_conn->selectValue('SELECT foo FROM autoinc WHERE bar = 6'));
+    }
+
+    public function testAutoIncrementWithChangeColumn()
+    {
+        $table = $this->_conn->createTable('autoinc', array('autoincrementKey' => false));
+        $table->column('foo', 'integer');
+        $table->column('bar', 'integer');
+        $table->end();
+        $this->_conn->changeColumn('autoinc', 'foo', 'autoincrementKey');
+
+        $this->assertEquals(1, $this->_conn->insert('INSERT INTO autoinc (bar) VALUES(5)'));
+        $this->assertEquals(2, $this->_conn->insert('INSERT INTO autoinc (bar) VALUES(6)'));
+        $this->assertEquals(2, $this->_conn->selectValue('SELECT foo FROM autoinc WHERE bar = 6'));
+    }
+
+
     /*##########################################################################
     # Table cache
     ##########################################################################*/
@@ -796,13 +918,13 @@ abstract class Horde_Db_Adapter_TestBase extends Horde_Test_Case
         $table = $this->_conn->createTable('unit_tests');
           $table->column('integer_value',   'integer',  array('limit' => 11, 'default' => 0));
           $table->column('string_value',    'string',   array('limit' => 255, 'default' => ''));
-          $table->column('text_value',      'text',     array('null' => false, 'default' => ''));
+          $table->column('text_value',      'text',     array());
           $table->column('float_value',     'float',    array('precision' => 2, 'default' => 0.0));
           $table->column('decimal_value',   'decimal',  array('precision' => 2, 'scale' => 1, 'default' => 0.0));
           $table->column('datetime_value',  'datetime', array());
           $table->column('date_value',      'date',     array());
           $table->column('time_value',      'time',     array());
-          $table->column('blob_value',      'binary',   array('null' => false, 'default' => ''));
+          $table->column('blob_value',      'binary',   array());
           $table->column('boolean_value',   'boolean',  array('default' => false));
           $table->column('email_value',     'string',   array('limit' => 255, 'default' => ''));
         $table->end();
@@ -864,6 +986,7 @@ abstract class Horde_Db_Adapter_TestBase extends Horde_Test_Case
     protected function _dropTestTables()
     {
         $tables = array(
+            'autoinc',
             'binary_testings',
             'cache_table',
             /* MySQL only? */
